<?php
/**
* VWT_hierarchicalMenu: Menu dynamique hierarchique
*
* Sample usage:
*
*   $hm = new VWT_hierarchicalMenu(200) ;
*   $hm->addFolder('Home',0);
*   $hm->addItem(0,'house.png','Welcome','index.php') ;
*   $hm->addItem(0,'www.png','Links','index.php?pageid=405') ;
*   $hm->addFolder('Screenshot',1);
*   $hm->addItem(1,'img.png','Login page','index.php?pageid=301&imgid=1') ;
*   $hm->addItem(1,'img.png','Main page','index.php?pageid=301&imgid=3') ;
*   $hm->addItem(1,'img.png','Preferences','index.php?pageid=301&imgid=2') ;
*   $hm->addFolder('Download',2);
*   $hm->addItem(2,'url.png','From Sourceforge','hmenu.sourceforge.net') ;
*   $hm->addItem(21,'url.png','Local','downlaod/hmenu-0.1.tar.gz') ;
*   echo $hm->getMenu() ;
*
* @author KDO
* @version 0.1
* @since 2002-04-17
* @copyright KDO / VWT (The Virtual Web Team)
* @package      VWT
* @subpackage   DHTML
*/
class VWT_hierarchicalMenu {

	/**
	* La structure du menu
	*
	* @vartype array
	* @access private
	*/
	var $menu;

	/**
	* Identifiant dossier (folder)
	*
	* @vartype array
	* @access private
	*/
	var $folder;

	/**
	* Compeur de liens par dossier
	*
	* @vartype int
	* @access private
	*/
	var $count;

	/**
	* Rsultat HTML
	*
	* @vartype string
	* @access private
	*/
	var $html;

	/**
	* Largeur du menu
	*
	* @vartype int
	* @access private
	*/
	var $width;
	
	/**
	* Constructeur de la classe
	*
	* Initialise les variables
	*
	* @param int $width Largeur du menu
	* @access public
	*/
	function VWT_hierarchicalMenu($width=240) {
		$this->menu = array() ;
		$this->folder = array() ;
		$this->count = 0 ;
		$this->html = '' ;
		$this->width = $width ;
	}

	/**
	* Ajoute une entre dossier au menu
	*
	* @param string $name Label du folder
	* @param mixed $id L'index du folder
	* @access public
	*/
	function addFolder($name, $id) {
		$this->count = 0 ;
		$this->folder[$id] = $name ;
	}
	
	/**
	* Construit le code HTML d'un header de folder
	*
	* @param mixed $id L'index du folder
	* @access private
	*/
	function getFolderHeader($id) {
		$f = $this->folder[$id] ;
		$jsid = 'HM_LEVEL_'.$id ;
		$this->html .= '<tr>'."\n";
		$this->html .= '<td class="hmhead" onMouseOver="this.className=\'hmheadover\'"';
		$this->html .= 'onMouseOut="this.className=\'hmheadout\'" onClick="javascript:showLevel( \''.$jsid.'\');">';
		$this->html .= '&nbsp;'.$f.'&nbsp;</td>'."\n";
		$this->html .= '</tr>'."\n";
		$this->html .= '<tr>'."\n";
		$this->html .=	'<td>'."\n";
		$this->html .=	'<table id="'.$jsid.'" width="100%" cellpadding="0"';
		$this->html .=	' cellspacing="0" border="0">'."\n";
	}

	/**
	* Parcours tous les folders pour construire le code HTML associ
	*
	* @access private
	*/
	function getFolders() {
		reset($this->menu) ;
		while(list($K, $V) = each($this->menu)) {
			$this->getFolderHeader($K);
			$this->getFolderItems($this->menu[$K]);
		}
	}

	/**
	* Construit le code HTML d'un item d'un folder
	*
	* @param array $T Le tableau des valeurs associes  un item
	* @access private
	*/
	function getItem($T) {/*
    $this->html .= '<tr class="hmlnkout" onMouseOver="this.className=\'hmlnkover\'"';
		$this->html .=	'onMouseOut="this.className=\'hmlnkout\'" onClick="window.location.href=\''.$T['link'].'\'">';
		$this->html .= '<td width="'.$this->width .'" class="hmlnk">';
		$this->html .= '<img src="'.$T['icon'].'" border="0"';
		$this->html .= ' align="center" />'.$T['label'].'</td></tr>'."\n";
		
    */
    $this->html .= '<tr class="hmlnkout" onMouseOver="this.className=\'hmlnkover\'"';
		$this->html .=	'onMouseOut="this.className=\'hmlnkout\'">';
		$this->html .= '<td width="'.$this->width .'"><a href="'.$T['link'].'" class="hmlnk">';
		$this->html .= '<img src="'.$T['icon'].'" border="0"';
		$this->html .= ' align="center" />'.$T['label'].'</a></td></tr>'."\n";
		
	}

	/**
	* Construit le code HTML des items d'un folder
	*
	* @param array $T Le tableau des items d'un folder
	* @access private
	*/
	function getFolderItems($T) {
		while(list($K, $V) = each($T)) {
			$this->getItem($T[$K]) ;
		}
		$this->html .=	'</table>'."\n";
		$this->html .= '</td>'."\n";
		$this->html .=	'</tr>'."\n";
	}

	/**
	* Construit le code javascript de la fonction hideAll()
	*
	* @access private
	*/
	function getJs() 
	{
		$this->html  = '<script language="JavaScript">'."\n";

		$this->html .= 'function hideLevel( _levelId ) {'."\n";
		$this->html .= 'var thisLevel = document.getElementById( _levelId );'."\n";
		$this->html .= 'thisLevel.style.display = "none";'."\n";
		$this->html .= '}'."\n\n";

		$this->html .= 'function showLevel( _levelId ) {'."\n";
		$this->html .= 'var thisLevel = document.getElementById( _levelId );'."\n";
		$this->html .= 'if ( thisLevel.style.display == "none") {'."\n";
		$this->html .= 'hideAll();'."\n\n";
		$this->html .= 'thisLevel.style.display = "block";'."\n";
		$this->html .= '}'."\n";	
		$this->html .= 'else {'."\n";
		$this->html .= 'hideLevel( _levelId);'."\n";
		$this->html .= '}'."\n";
		$this->html .= '}'."\n\n";
	
		$this->html .= 'function hideAll() {'."\n";
		reset($this->folder);
		while(list($K, $V) = each($this->folder)) {
			$this->html .= '   hideLevel("HM_LEVEL_'.$K.'");'."\n";
		}
		$this->html .= '}'."\n";
		$this->html .= '</script>'."\n";
	}
	
	/**
	* Construit le footer HTML du menu
	*
	* @access private
	*/
	function getMenufooter() {
		$this->html .= '</table>'."\n";
		$this->html .= '</div>'."\n";
	}

	/**
	* Construit le header HTML du menu
	*
	* @access private
	*/
	function getMenuHeader() {
		$this->html .= '<div>'."\n";
		$this->html .= '<table class="hmbody" cellpadding="0" cellspacing="0" border="0"';
		$this->html .= ' width="'. $this->width . '">'."\n";
	}
	
	/**
	* Construit et renvoie le source HTML du menu
	*
	* @param mixed $open index du folder  ouvrir au dmarrage
	* @return string le contenu HRML
	* @access public
	*/
	function getMenu($open='NONE') {
		$this->getJs() ;
		$this->getMenuHeader() ;
		$this->getFolders() ;
		$this->getMenuFooter() ;
		$this->jsGetStart($open);
		return $this->html ;
	}

	/**
	* Construit le code js de dmarrage du menu
	*
	* @access private
	*/
	function jsGetStart($id) {
		$jsid = 'HM_LEVEL_'.$id ;
		$this->html .= '<script language="JavaScript">'."\n";
		$this->html .= "hideAll();\n";
		if ($id <> 'NONE') {
			$this->html .= "showLevel('$jsid');\n";
		}
		$this->html .= '</script>'."\n";
	}

	/**
	* Cre les items d'un folder donn
	*
	* @param mixed $folder index du folder contenant l'item
	* @param string $icon chemin de l'icone
	* @param string $label texte associ au lien
	* @param string $link url de destination
	* @access private
	*/
	function addItem($folder, $icon, $label, $link) {
		$index = $this->count ;
		$this->menu[$folder][$index]['icon']  = $icon  ;
		$this->menu[$folder][$index]['link']  = $link  ;
		$this->menu[$folder][$index]['label'] = $label ;
		$this->count += 1;
	}
}

?>
